@@ -11,6 +11,12 @@
 /* DESCRIPTION
 /* .nf
 
+ /*
+  * System library.
+  */
+#include <sys_defs.h>
+#include <stdarg.h>
+
  /*
   * Utility library.
   */
@@ -128,6 +134,9 @@ typedef struct VSTREAM _deliver_vstream_;
 extern DELIVER_REQUEST *deliver_request_read(_deliver_vstream_ *);
 extern int deliver_request_done(_deliver_vstream_ *, DELIVER_REQUEST *, int);
 
+extern int PRINTFLIKE(4, 5) reject_deliver_request(const char *,
+		         DELIVER_REQUEST *, const char *, const char *,...);
+
 /* LICENSE
 /* .ad
 /* .fi
